@@ -5,8 +5,18 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
+
+#' @templateVar name AlterSwap
+#' @aliases InitWtErgmProposal.AlterSwap
+#' @title A proposal that swaps values of two alters incident on an ego
+#' @description This proposal randomly selects two dyads \eqn{(i,j)} and \eqn{(i,j')} with a common sender and proposes to swap their values if distinct.
+#' @template ergmProposal-general
+#' @concept valued
+#' @concept ordinal
+NULL
+
 InitWtErgmProposal.AlterSwap <- function(arguments, nw) {
   MHproposal <- list(name = "AlterSwap", inputs=NULL)
   MHproposal
