@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
 #' @useDynLib ergm.rank
 #' @import statnet.common ergm network
@@ -16,8 +16,13 @@
 
 .onLoad <- function(libname, pkgname){
   .RegisterProposals()
+  .RegisterKeywords()
 }
 
 .RegisterProposals <- function(){
   ergm_proposal_table("c", "CompleteOrder", "",  0, "random", "AlterSwap")
 }
+
+.RegisterKeywords <- function(){
+  ergm_keyword(name="ordinal", short="ordinal", description="depends on edge values only through their rank among other edge values", popular=TRUE, package="ergm.rank")
+}
